@@ -4,13 +4,13 @@ Attean - A Semantic Web Framework
 
 =head1 VERSION
 
-This document describes Attean version 0.025_01
+This document describes Attean version 0.026_01
 
 =head1 SYNOPSIS
 
-  use v5.14;
   use Attean;
   use Attean::RDF qw(iri);
+  
   my $store = Attean->get_store('Memory')->new();
   my $parser = Attean->get_parser('NTriples')->new();
   
@@ -18,7 +18,8 @@ This document describes Attean version 0.025_01
   my $iter = $parser->parse_iter_from_io(\*STDIN);
   
   # add a graph name to all triples
-  my $quads = $iter->as_quads(iri('http://graph-name/'));
+  my $graph = iri('http://graph-name/');
+  my $quads = $iter->as_quads($graph);
   
   $store->add_iter($quads);
   my $model = Attean::QuadModel->new( store => $store );
@@ -27,6 +28,15 @@ This document describes Attean version 0.025_01
     say $quad->object->ntriples_string;
   }
 
+  # run a SPARQL query and iterate over the results
+  my $sparql = 'SELECT * WHERE { ?s ?p ?o }';
+  my $s = Attean->get_parser('SPARQL')->new();
+  my ($algebra)	= $s->parse($sparql);
+  my $results = $model->evaluate($algebra, $graph);
+  while (my $r = $results->next) {
+    say $r->as_string;
+  }
+
 =head1 DESCRIPTION
 
 Attean provides APIs for parsing, storing, querying, and serializing
@@ -41,7 +51,7 @@ Semantic Web (RDF and SPARQL) data.
 package Attean {
 	use v5.14;
 	use warnings;
-	our $VERSION	= '0.025_01';
+	our $VERSION	= '0.026_01';
 	use Attean::API;
 	
 	use Attean::Blank;
@@ -414,7 +424,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2019 Gregory Todd Williams.
+Copyright (c) 2014--2020 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
