@@ -7,7 +7,7 @@ Attean::API::Binding - Name to term bindings
 
 =head1 VERSION
 
-This document describes Attean::API::Binding version 0.024
+This document describes Attean::API::Binding version 0.026
 
 =head1 DESCRIPTION
 
@@ -71,7 +71,7 @@ otherwise.
 
 use Type::Tiny::Role;
 
-package Attean::API::Binding 0.024 {
+package Attean::API::Binding 0.026 {
 	use Scalar::Util qw(blessed);
 	use List::MoreUtils qw(zip);
 
@@ -173,7 +173,7 @@ C<< $binding >>.
 	}
 }
 
-package Attean::API::TripleOrQuadPattern 0.024 {
+package Attean::API::TripleOrQuadPattern 0.026 {
 	use Encode qw(encode);
 	use List::MoreUtils qw(zip);
 	use Scalar::Util qw(blessed);
@@ -279,7 +279,7 @@ parsed from C<< $string >> in SPARQL syntax.
 	}
 }
 
-package Attean::API::TripleOrQuad 0.024 {
+package Attean::API::TripleOrQuad 0.026 {
 	use List::MoreUtils qw(any);
 	use Carp;
 
@@ -295,7 +295,7 @@ package Attean::API::TripleOrQuad 0.024 {
 	}
 }
 
-package Attean::API::TriplePattern 0.024 {
+package Attean::API::TriplePattern 0.026 {
 	use List::MoreUtils qw(zip);
 	use Scalar::Util qw(blessed);
 
@@ -347,7 +347,7 @@ package Attean::API::TriplePattern 0.024 {
 	with 'Attean::API::TripleOrQuadPattern', 'Attean::API::Binding';
 }
 
-package Attean::API::Triple 0.024 {
+package Attean::API::Triple 0.026 {
 	use Moo::Role;
 	
 	if ($ENV{ATTEAN_TYPECHECK}) {
@@ -382,7 +382,7 @@ package Attean::API::Triple 0.024 {
 	with 'Attean::API::TriplePattern', 'Attean::API::TripleOrQuad', 'Attean::API::Binding';
 }
 
-package Attean::API::QuadPattern 0.024 {
+package Attean::API::QuadPattern 0.026 {
 	use Scalar::Util qw(blessed);
 	use List::MoreUtils qw(zip);
 
@@ -439,7 +439,7 @@ package Attean::API::QuadPattern 0.024 {
 	with 'Attean::API::TripleOrQuadPattern', 'Attean::API::Binding';
 }
 
-package Attean::API::Quad 0.024 {
+package Attean::API::Quad 0.026 {
 	use Moo::Role;
 	
 	if ($ENV{ATTEAN_TYPECHECK}) {
@@ -466,7 +466,7 @@ package Attean::API::Quad 0.024 {
 }
 
 
-package Attean::API::Result 0.024 {
+package Attean::API::Result 0.026 {
 	use Scalar::Util qw(refaddr);
 	use Types::Standard qw(HashRef);
 
@@ -547,7 +547,13 @@ from the invocant for every variable name in C<< @keys >>.
 		my $self	= shift;
 		my $class	= ref($self);
 		my $mapper	= shift;
-		my %values	= map { $_ => $mapper->map($self->value($_)) } $self->variables;
+		my %values;
+		foreach my $var ($self->variables) {
+			my $term	= $mapper->map($self->value($var));
+			if ($term) {
+				$values{$var}	= $term;
+			}
+		}
 		return $class->new( bindings => \%values );
 	}
 
@@ -575,7 +581,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2019 Gregory Todd Williams.
+Copyright (c) 2014--2020 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
